@@ -11,7 +11,7 @@ class BatteryBME(AbstractBattery):
 
   def pre_init(self):
     self.friendly_name = 'Nokia\'s BME'
-    self.dep_packages = {'hald-addon-bme': '0.0.4'}
+    self.depends['packages'] = {'hald-addon-bme': '0.0.4'}
     self.interfaces_map = {'BME': ('org.freedesktop.Hal', '/org/freedesktop/Hal/devices/bme', 'org.freedesktop.Hal.Device')}
     self.export_signals = {'battery_charger_is_connected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_charging_on'},
                            'battery_charger_is_disconnected': {'path': '/com/nokia/bme/signal', 'dbus_interface': 'com.nokia.bme.signal', 'signal_name': 'charger_disconnected'},
